module GitHub::Payload::Formatter
  class Parser
    attr_accessor :payload
    def initialize(payload)
      @payload = payload
    end
    
    def summary_message
      summarizer.summary_message
    end

    def summary_url
      summarizer.summary_url
    end

    def summarizer
      @summarizer ||=
        case payload['event']
        when 'push'
          PushEvent.new(payload)
        when 'create'
          CreateEvent.new(payload)
        when 'delete'
          DeleteEvent.new(payload)
        when 'public'
          PublicEvent.new(payload)
        when 'issues'
          IssuesEvent.new(payload)
        when 'pull_request'
          PullRequestEvent.new(payload)
        when 'issue_comment'
          IssueCommentEvent.new(payload)
        when 'pull_request_review_comment'
          warn 'unsupported payload type pull_request_review_comment'
        else
          puts payload['event']
        end
    end
  end

  class Event
    include GitHub::Payload::Formatter

    attr_accessor :payload
    def initialize(payload)
      @payload = payload['payload']
    end

    def self.objectify(hash)
      struct = OpenStruct.new
      hash.each do |key, value|
        struct.send("#{key}=", value.is_a?(Hash) ? objectify(value) : value)
      end
      struct
    end
  end
end
require 'github/payload/formatter/create_event'
require 'github/payload/formatter/delete_event'
require 'github/payload/formatter/issue_comment_event'
require 'github/payload/formatter/issues_event'
require 'github/payload/formatter/public_event'
require 'github/payload/formatter/pull_request_event'
require 'github/payload/formatter/push_event'

